# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-22 10:21
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(blank=True, upload_to=b'event-images')),
                ('where', models.CharField(max_length=200)),
                ('what', models.TextField()),
                ('what_html', models.TextField(blank=True, editable=False)),
                ('start_date', models.DateField()),
                ('end_date', models.DateField()),
                ('published_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]
